==> ecs-patterns-1.26.0-sources.jar: software/amazon/awscdk/services/ecs/patterns/ApplicationMultipleTargetGroupsServiceBase.java <==
package software.amazon.awscdk.services.ecs.patterns;

/**
 * The base class for ApplicationMultipleTargetGroupsEc2Service and ApplicationMultipleTargetGroupsFargateService classes.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.22.0 (build 14afdde)", date = "2020-02-26T08:39:03.190Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ecs.patterns.$Module.class, fqn = "@aws-cdk/aws-ecs-patterns.ApplicationMultipleTargetGroupsServiceBase")
public abstract class ApplicationMultipleTargetGroupsServiceBase extends software.amazon.awscdk.core.Construct {

    protected ApplicationMultipleTargetGroupsServiceBase(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ApplicationMultipleTargetGroupsServiceBase(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * Constructs a new instance of the ApplicationMultipleTargetGroupsServiceBase class.
     * <p>
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected ApplicationMultipleTargetGroupsServiceBase(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ecs.patterns.ApplicationMultipleTargetGroupsServiceBaseProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), props });
    }

    /**
     * Constructs a new instance of the ApplicationMultipleTargetGroupsServiceBase class.
     * <p>
     * @param scope This parameter is required.
     * @param id This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected ApplicationMultipleTargetGroupsServiceBase(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required") });
    }

    /**
     * @param container This parameter is required.
     * @param targets This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected void addPortMappingForTargets(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.ContainerDefinition container, final @org.jetbrains.annotations.NotNull java.util.List<software.amazon.awscdk.services.ecs.patterns.ApplicationTargetProps> targets) {
        this.jsiiCall("addPortMappingForTargets", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(container, "container is required"), java.util.Objects.requireNonNull(targets, "targets is required") });
    }

    /**
     * @param prefix This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.AwsLogDriver createAWSLogDriver(final @org.jetbrains.annotations.NotNull java.lang.String prefix) {
        return this.jsiiCall("createAWSLogDriver", software.amazon.awscdk.services.ecs.AwsLogDriver.class, new Object[] { java.util.Objects.requireNonNull(prefix, "prefix is required") });
    }

    /**
     * @param name
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationListener findListener(final @org.jetbrains.annotations.Nullable java.lang.String name) {
        return this.jsiiCall("findListener", software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationListener.class, new Object[] { name });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationListener findListener() {
        return this.jsiiCall("findListener", software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationListener.class);
    }

    /**
     * Returns the default cluster.
     * <p>
     * @param scope This parameter is required.
     * @param vpc
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.Cluster getDefaultCluster(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ec2.IVpc vpc) {
        return this.jsiiCall("getDefaultCluster", software.amazon.awscdk.services.ecs.Cluster.class, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), vpc });
    }

    /**
     * Returns the default cluster.
     * <p>
     * @param scope This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.Cluster getDefaultCluster(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope) {
        return this.jsiiCall("getDefaultCluster", software.amazon.awscdk.services.ecs.Cluster.class, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required") });
    }

    /**
     * @param service This parameter is required.
     * @param container This parameter is required.
     * @param targets This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationTargetGroup registerECSTargets(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.BaseService service, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.ContainerDefinition container, final @org.jetbrains.annotations.NotNull java.util.List<software.amazon.awscdk.services.ecs.patterns.ApplicationTargetProps> targets) {
        return this.jsiiCall("registerECSTargets", software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationTargetGroup.class, new Object[] { java.util.Objects.requireNonNull(service, "service is required"), java.util.Objects.requireNonNull(container, "container is required"), java.util.Objects.requireNonNull(targets, "targets is required") });
    }

    /**
     * The cluster that hosts the service.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.ICluster getCluster() {
        return this.jsiiGet("cluster", software.amazon.awscdk.services.ecs.ICluster.class);
    }

    /**
     * The desired number of instantiations of the task definition to keep running on the service.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.Number getDesiredCount() {
        return this.jsiiGet("desiredCount", java.lang.Number.class);
    }

    /**
     * The default listener for the service (first added listener).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationListener getListener() {
        return this.jsiiGet("listener", software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationListener.class);
    }

    /**
     * The default Application Load Balancer for the service (first added load balancer).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationLoadBalancer getLoadBalancer() {
        return this.jsiiGet("loadBalancer", software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationLoadBalancer.class);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected @org.jetbrains.annotations.NotNull java.util.List<software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationListener> getListeners() {
        return java.util.Collections.unmodifiableList(this.jsiiGet("listeners", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationListener.class))));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected void setListeners(final @org.jetbrains.annotations.NotNull java.util.List<software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationListener> value) {
        this.jsiiSet("listeners", java.util.Objects.requireNonNull(value, "listeners is required"));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected @org.jetbrains.annotations.NotNull java.util.List<software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationTargetGroup> getTargetGroups() {
        return java.util.Collections.unmodifiableList(this.jsiiGet("targetGroups", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationTargetGroup.class))));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected void setTargetGroups(final @org.jetbrains.annotations.NotNull java.util.List<software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationTargetGroup> value) {
        this.jsiiSet("targetGroups", java.util.Objects.requireNonNull(value, "targetGroups is required"));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ecs.LogDriver getLogDriver() {
        return this.jsiiGet("logDriver", software.amazon.awscdk.services.ecs.LogDriver.class);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected void setLogDriver(final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ecs.LogDriver value) {
        this.jsiiSet("logDriver", value);
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.awscdk.services.ecs.patterns.ApplicationMultipleTargetGroupsServiceBase {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * The construct node in the tree.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.ConstructNode getNode() {
            return this.jsiiGet("node", software.amazon.awscdk.core.ConstructNode.class);
        }
    }
}

==> ecs-patterns-1.35.0-sources.jar: software/amazon/awscdk/services/ecs/patterns/ApplicationMultipleTargetGroupsServiceBase.java <==
package software.amazon.awscdk.services.ecs.patterns;

/**
 * The base class for ApplicationMultipleTargetGroupsEc2Service and ApplicationMultipleTargetGroupsFargateService classes.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.4.1 (build 0b09d7b)", date = "2020-04-24T11:27:21.905Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ecs.patterns.$Module.class, fqn = "@aws-cdk/aws-ecs-patterns.ApplicationMultipleTargetGroupsServiceBase")
public abstract class ApplicationMultipleTargetGroupsServiceBase extends software.amazon.awscdk.core.Construct {

    protected ApplicationMultipleTargetGroupsServiceBase(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ApplicationMultipleTargetGroupsServiceBase(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * Constructs a new instance of the ApplicationMultipleTargetGroupsServiceBase class.
     * <p>
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected ApplicationMultipleTargetGroupsServiceBase(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ecs.patterns.ApplicationMultipleTargetGroupsServiceBaseProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), props });
    }

    /**
     * Constructs a new instance of the ApplicationMultipleTargetGroupsServiceBase class.
     * <p>
     * @param scope This parameter is required.
     * @param id This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected ApplicationMultipleTargetGroupsServiceBase(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required") });
    }

    /**
     * @param container This parameter is required.
     * @param targets This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected void addPortMappingForTargets(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.ContainerDefinition container, final @org.jetbrains.annotations.NotNull java.util.List<software.amazon.awscdk.services.ecs.patterns.ApplicationTargetProps> targets) {
        this.jsiiCall("addPortMappingForTargets", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(container, "container is required"), java.util.Objects.requireNonNull(targets, "targets is required") });
    }

    /**
     * @param prefix This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.AwsLogDriver createAWSLogDriver(final @org.jetbrains.annotations.NotNull java.lang.String prefix) {
        return this.jsiiCall("createAWSLogDriver", software.amazon.awscdk.services.ecs.AwsLogDriver.class, new Object[] { java.util.Objects.requireNonNull(prefix, "prefix is required") });
    }

    /**
     * @param name
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationListener findListener(final @org.jetbrains.annotations.Nullable java.lang.String name) {
        return this.jsiiCall("findListener", software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationListener.class, new Object[] { name });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationListener findListener() {
        return this.jsiiCall("findListener", software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationListener.class);
    }

    /**
     * Returns the default cluster.
     * <p>
     * @param scope This parameter is required.
     * @param vpc
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.Cluster getDefaultCluster(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ec2.IVpc vpc) {
        return this.jsiiCall("getDefaultCluster", software.amazon.awscdk.services.ecs.Cluster.class, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), vpc });
    }

    /**
     * Returns the default cluster.
     * <p>
     * @param scope This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.Cluster getDefaultCluster(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope) {
        return this.jsiiCall("getDefaultCluster", software.amazon.awscdk.services.ecs.Cluster.class, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required") });
    }

    /**
     * @param service This parameter is required.
     * @param container This parameter is required.
     * @param targets This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationTargetGroup registerECSTargets(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.BaseService service, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.ContainerDefinition container, final @org.jetbrains.annotations.NotNull java.util.List<software.amazon.awscdk.services.ecs.patterns.ApplicationTargetProps> targets) {
        return this.jsiiCall("registerECSTargets", software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationTargetGroup.class, new Object[] { java.util.Objects.requireNonNull(service, "service is required"), java.util.Objects.requireNonNull(container, "container is required"), java.util.Objects.requireNonNull(targets, "targets is required") });
    }

    /**
     * The cluster that hosts the service.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.ICluster getCluster() {
        return this.jsiiGet("cluster", software.amazon.awscdk.services.ecs.ICluster.class);
    }

    /**
     * The desired number of instantiations of the task definition to keep running on the service.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.Number getDesiredCount() {
        return this.jsiiGet("desiredCount", java.lang.Number.class);
    }

    /**
     * The default listener for the service (first added listener).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationListener getListener() {
        return this.jsiiGet("listener", software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationListener.class);
    }

    /**
     * The default Application Load Balancer for the service (first added load balancer).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationLoadBalancer getLoadBalancer() {
        return this.jsiiGet("loadBalancer", software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationLoadBalancer.class);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected @org.jetbrains.annotations.NotNull java.util.List<software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationListener> getListeners() {
        return java.util.Collections.unmodifiableList(this.jsiiGet("listeners", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationListener.class))));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected void setListeners(final @org.jetbrains.annotations.NotNull java.util.List<software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationListener> value) {
        this.jsiiSet("listeners", java.util.Objects.requireNonNull(value, "listeners is required"));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected @org.jetbrains.annotations.NotNull java.util.List<software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationTargetGroup> getTargetGroups() {
        return java.util.Collections.unmodifiableList(this.jsiiGet("targetGroups", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationTargetGroup.class))));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected void setTargetGroups(final @org.jetbrains.annotations.NotNull java.util.List<software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationTargetGroup> value) {
        this.jsiiSet("targetGroups", java.util.Objects.requireNonNull(value, "targetGroups is required"));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ecs.LogDriver getLogDriver() {
        return this.jsiiGet("logDriver", software.amazon.awscdk.services.ecs.LogDriver.class);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected void setLogDriver(final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ecs.LogDriver value) {
        this.jsiiSet("logDriver", value);
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.awscdk.services.ecs.patterns.ApplicationMultipleTargetGroupsServiceBase {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * The construct tree node for this construct.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.ConstructNode getNode() {
            return this.jsiiGet("node", software.amazon.awscdk.core.ConstructNode.class);
        }
    }
}
